@@ -1,4 +1,5 @@
 var assert = require('assert'),
+    Buffer = require('safer-buffer').Buffer,
     iconv = require(__dirname+'/../');
 
 describe("CESU-8 codec", function() {
@@ -13,11 +14,11 @@ describe("CESU-8 codec", function() {
         assert.equal(iconv.encode("😱😱", "cesu8").toString('hex'), "eda0bdedb8b1eda0bdedb8b1");
     });
     it("decodes correctly", function() {
-        assert.equal(iconv.decode(new Buffer("45", 'hex'), "cesu8"), "E");
-        assert.equal(iconv.decode(new Buffer("c2a2", 'hex'), "cesu8"), "¢");
-        assert.equal(iconv.decode(new Buffer("c885", 'hex'), "cesu8"), "ȅ");
-        assert.equal(iconv.decode(new Buffer("e282ac", 'hex'), "cesu8"), "€");
-        assert.equal(iconv.decode(new Buffer("eda081edb080", 'hex'), "cesu8"), "𐐀");
-        assert.equal(iconv.decode(new Buffer("eda0bdedb8b1", 'hex'), "cesu8"), "😱");
+        assert.equal(iconv.decode(Buffer.from("45", 'hex'), "cesu8"), "E");
+        assert.equal(iconv.decode(Buffer.from("c2a2", 'hex'), "cesu8"), "¢");
+        assert.equal(iconv.decode(Buffer.from("c885", 'hex'), "cesu8"), "ȅ");
+        assert.equal(iconv.decode(Buffer.from("e282ac", 'hex'), "cesu8"), "€");
+        assert.equal(iconv.decode(Buffer.from("eda081edb080", 'hex'), "cesu8"), "𐐀");
+        assert.equal(iconv.decode(Buffer.from("eda0bdedb8b1", 'hex'), "cesu8"), "😱");
     });
 });
